[vlc-commits] file access: rename callbacks

Rafaël Carré git at videolan.org
Wed Aug 31 06:22:34 CEST 2011


vlc | branch: master | Rafaël Carré <rafael.carre at gmail.com> | Wed Aug 31 00:19:58 2011 -0400| [0ed6e06dabf189a7ada1061343f876817d63b24a] | committer: Rafaël Carré

file access: rename callbacks

avoid having extern Open() symbol defined multiple times in static builds

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=0ed6e06dabf189a7ada1061343f876817d63b24a
---

 modules/access/file.c |    8 ++++----
 modules/access/fs.c   |    2 +-
 modules/access/fs.h   |    4 ++--
 3 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/modules/access/fs.c b/modules/access/fs.c
index ff8a7e5..5fb16dc 100644
--- a/modules/access/fs.c
+++ b/modules/access/fs.c
@@ -56,7 +56,7 @@ vlc_module_begin ()
     add_obsolete_string( "file-cat" )
     set_capability( "access", 50 )
     add_shortcut( "file", "fd", "stream" )
-    set_callbacks( Open, Close )
+    set_callbacks( FileOpen, FileClose )
 
     add_submodule()
     set_section( N_("Directory" ), NULL )
diff --git a/modules/access/fs.h b/modules/access/fs.h
index de5e493..afc090f 100644
--- a/modules/access/fs.h
+++ b/modules/access/fs.h
@@ -20,8 +20,8 @@
 
 #include <dirent.h>
 
-int Open (vlc_object_t *);
-void Close (vlc_object_t *);
+int FileOpen (vlc_object_t *);
+void FileClose (vlc_object_t *);
 int NoSeek (access_t *, uint64_t);
 
 ssize_t FileRead (access_t *, uint8_t *, size_t);



More information about the vlc-commits mailing list
diff --git a/modules/access/file.c b/modules/access/file.c
index b690b8d..4e9761e 100644
--- a/modules/access/file.c
+++ b/modules/access/file.c
@@ -129,9 +129,9 @@ static bool IsRemote (int fd)
 #endif
 
 /*****************************************************************************
  * Open: open the file
  *****************************************************************************/
-int Open( vlc_object_t *p_this )
+int FileOpen( vlc_object_t *p_this )
 {
     access_t     *p_access = (access_t*)p_this;
 #ifdef WIN32
@@ -242,9 +242,9 @@ error:
 }
 
 /*****************************************************************************
  * Close: close the target
  *****************************************************************************/
-void Close (vlc_object_t * p_this)
+void FileClose (vlc_object_t * p_this)
 {
     access_t     *p_access = (access_t*)p_this;
 
@@ -129,9 +129,9 @@ static bool IsRemote (int fd)
 
 /*****************************************************************************
- * Open: open the file
+ * FileOpen: open the file
  *****************************************************************************/
@@ -242,9 +242,9 @@ error:
 
 /*****************************************************************************
- * Close: close the target
+ * FileClose: close the target
  *****************************************************************************/